# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['RepoRuleBranchArgs', 'RepoRuleBranch']

@pulumi.input_type
class RepoRuleBranchArgs:
    def __init__(__self__, *,
                 bypasses: pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchBypassArgs']]],
                 identifier: pulumi.Input[_builtins.str],
                 policies: pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchPolicyArgs']]],
                 repo_identifier: pulumi.Input[_builtins.str],
                 state: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 patterns: Optional[pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchPatternArgs']]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a RepoRuleBranch resource.
        :param pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchBypassArgs']]] bypasses: List of users who can bypass this rule.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the rule.
        :param pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchPolicyArgs']]] policies: Policies to be applied for this rule.
        :param pulumi.Input[_builtins.str] repo_identifier: Repo identifier of the repository.
        :param pulumi.Input[_builtins.str] state: State of the rule (active, disable, monitor).
        :param pulumi.Input[_builtins.str] description: Description of the rule.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchPatternArgs']]] patterns: Pattern of branch to which rule will apply.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        """
        pulumi.set(__self__, "bypasses", bypasses)
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "policies", policies)
        pulumi.set(__self__, "repo_identifier", repo_identifier)
        pulumi.set(__self__, "state", state)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if patterns is not None:
            pulumi.set(__self__, "patterns", patterns)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)

    @_builtins.property
    @pulumi.getter
    def bypasses(self) -> pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchBypassArgs']]]:
        """
        List of users who can bypass this rule.
        """
        return pulumi.get(self, "bypasses")

    @bypasses.setter
    def bypasses(self, value: pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchBypassArgs']]]):
        pulumi.set(self, "bypasses", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Identifier of the rule.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def policies(self) -> pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchPolicyArgs']]]:
        """
        Policies to be applied for this rule.
        """
        return pulumi.get(self, "policies")

    @policies.setter
    def policies(self, value: pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchPolicyArgs']]]):
        pulumi.set(self, "policies", value)

    @_builtins.property
    @pulumi.getter(name="repoIdentifier")
    def repo_identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Repo identifier of the repository.
        """
        return pulumi.get(self, "repo_identifier")

    @repo_identifier.setter
    def repo_identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "repo_identifier", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> pulumi.Input[_builtins.str]:
        """
        State of the rule (active, disable, monitor).
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "state", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the rule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter
    def patterns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchPatternArgs']]]]:
        """
        Pattern of branch to which rule will apply.
        """
        return pulumi.get(self, "patterns")

    @patterns.setter
    def patterns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchPatternArgs']]]]):
        pulumi.set(self, "patterns", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)


@pulumi.input_type
class _RepoRuleBranchState:
    def __init__(__self__, *,
                 bypasses: Optional[pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchBypassArgs']]]] = None,
                 created: Optional[pulumi.Input[_builtins.int]] = None,
                 created_by: Optional[pulumi.Input[_builtins.int]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 patterns: Optional[pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchPatternArgs']]]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchPolicyArgs']]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None,
                 updated: Optional[pulumi.Input[_builtins.int]] = None,
                 updated_by: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering RepoRuleBranch resources.
        :param pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchBypassArgs']]] bypasses: List of users who can bypass this rule.
        :param pulumi.Input[_builtins.int] created: Timestamp when the rule was created.
        :param pulumi.Input[_builtins.int] created_by: ID of the user who created the rule.
        :param pulumi.Input[_builtins.str] description: Description of the rule.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the rule.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchPatternArgs']]] patterns: Pattern of branch to which rule will apply.
        :param pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchPolicyArgs']]] policies: Policies to be applied for this rule.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] repo_identifier: Repo identifier of the repository.
        :param pulumi.Input[_builtins.str] state: State of the rule (active, disable, monitor).
        :param pulumi.Input[_builtins.int] updated: Timestamp when the rule was updated.
        :param pulumi.Input[_builtins.int] updated_by: ID of the user who updated the rule.
        """
        if bypasses is not None:
            pulumi.set(__self__, "bypasses", bypasses)
        if created is not None:
            pulumi.set(__self__, "created", created)
        if created_by is not None:
            pulumi.set(__self__, "created_by", created_by)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if patterns is not None:
            pulumi.set(__self__, "patterns", patterns)
        if policies is not None:
            pulumi.set(__self__, "policies", policies)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if repo_identifier is not None:
            pulumi.set(__self__, "repo_identifier", repo_identifier)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if updated is not None:
            pulumi.set(__self__, "updated", updated)
        if updated_by is not None:
            pulumi.set(__self__, "updated_by", updated_by)

    @_builtins.property
    @pulumi.getter
    def bypasses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchBypassArgs']]]]:
        """
        List of users who can bypass this rule.
        """
        return pulumi.get(self, "bypasses")

    @bypasses.setter
    def bypasses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchBypassArgs']]]]):
        pulumi.set(self, "bypasses", value)

    @_builtins.property
    @pulumi.getter
    def created(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timestamp when the rule was created.
        """
        return pulumi.get(self, "created")

    @created.setter
    def created(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created", value)

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        ID of the user who created the rule.
        """
        return pulumi.get(self, "created_by")

    @created_by.setter
    def created_by(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "created_by", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the rule.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Identifier of the rule.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter
    def patterns(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchPatternArgs']]]]:
        """
        Pattern of branch to which rule will apply.
        """
        return pulumi.get(self, "patterns")

    @patterns.setter
    def patterns(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchPatternArgs']]]]):
        pulumi.set(self, "patterns", value)

    @_builtins.property
    @pulumi.getter
    def policies(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchPolicyArgs']]]]:
        """
        Policies to be applied for this rule.
        """
        return pulumi.get(self, "policies")

    @policies.setter
    def policies(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['RepoRuleBranchPolicyArgs']]]]):
        pulumi.set(self, "policies", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="repoIdentifier")
    def repo_identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Repo identifier of the repository.
        """
        return pulumi.get(self, "repo_identifier")

    @repo_identifier.setter
    def repo_identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "repo_identifier", value)

    @_builtins.property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        State of the rule (active, disable, monitor).
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "state", value)

    @_builtins.property
    @pulumi.getter
    def updated(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Timestamp when the rule was updated.
        """
        return pulumi.get(self, "updated")

    @updated.setter
    def updated(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "updated", value)

    @_builtins.property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        ID of the user who updated the rule.
        """
        return pulumi.get(self, "updated_by")

    @updated_by.setter
    def updated_by(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "updated_by", value)


@pulumi.type_token("harness:platform/repoRuleBranch:RepoRuleBranch")
class RepoRuleBranch(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bypasses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepoRuleBranchBypassArgs', 'RepoRuleBranchBypassArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 patterns: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepoRuleBranchPatternArgs', 'RepoRuleBranchPatternArgsDict']]]]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepoRuleBranchPolicyArgs', 'RepoRuleBranchPolicyArgsDict']]]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a Harness Repo Branch Rule.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RepoRuleBranchBypassArgs', 'RepoRuleBranchBypassArgsDict']]]] bypasses: List of users who can bypass this rule.
        :param pulumi.Input[_builtins.str] description: Description of the rule.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the rule.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RepoRuleBranchPatternArgs', 'RepoRuleBranchPatternArgsDict']]]] patterns: Pattern of branch to which rule will apply.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RepoRuleBranchPolicyArgs', 'RepoRuleBranchPolicyArgsDict']]]] policies: Policies to be applied for this rule.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] repo_identifier: Repo identifier of the repository.
        :param pulumi.Input[_builtins.str] state: State of the rule (active, disable, monitor).
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RepoRuleBranchArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness Repo Branch Rule.

        :param str resource_name: The name of the resource.
        :param RepoRuleBranchArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RepoRuleBranchArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bypasses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepoRuleBranchBypassArgs', 'RepoRuleBranchBypassArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 patterns: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepoRuleBranchPatternArgs', 'RepoRuleBranchPatternArgsDict']]]]] = None,
                 policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepoRuleBranchPolicyArgs', 'RepoRuleBranchPolicyArgsDict']]]]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 repo_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 state: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RepoRuleBranchArgs.__new__(RepoRuleBranchArgs)

            if bypasses is None and not opts.urn:
                raise TypeError("Missing required property 'bypasses'")
            __props__.__dict__["bypasses"] = bypasses
            __props__.__dict__["description"] = description
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["patterns"] = patterns
            if policies is None and not opts.urn:
                raise TypeError("Missing required property 'policies'")
            __props__.__dict__["policies"] = policies
            __props__.__dict__["project_id"] = project_id
            if repo_identifier is None and not opts.urn:
                raise TypeError("Missing required property 'repo_identifier'")
            __props__.__dict__["repo_identifier"] = repo_identifier
            if state is None and not opts.urn:
                raise TypeError("Missing required property 'state'")
            __props__.__dict__["state"] = state
            __props__.__dict__["created"] = None
            __props__.__dict__["created_by"] = None
            __props__.__dict__["updated"] = None
            __props__.__dict__["updated_by"] = None
        super(RepoRuleBranch, __self__).__init__(
            'harness:platform/repoRuleBranch:RepoRuleBranch',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bypasses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepoRuleBranchBypassArgs', 'RepoRuleBranchBypassArgsDict']]]]] = None,
            created: Optional[pulumi.Input[_builtins.int]] = None,
            created_by: Optional[pulumi.Input[_builtins.int]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            patterns: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepoRuleBranchPatternArgs', 'RepoRuleBranchPatternArgsDict']]]]] = None,
            policies: Optional[pulumi.Input[Sequence[pulumi.Input[Union['RepoRuleBranchPolicyArgs', 'RepoRuleBranchPolicyArgsDict']]]]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            repo_identifier: Optional[pulumi.Input[_builtins.str]] = None,
            state: Optional[pulumi.Input[_builtins.str]] = None,
            updated: Optional[pulumi.Input[_builtins.int]] = None,
            updated_by: Optional[pulumi.Input[_builtins.int]] = None) -> 'RepoRuleBranch':
        """
        Get an existing RepoRuleBranch resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RepoRuleBranchBypassArgs', 'RepoRuleBranchBypassArgsDict']]]] bypasses: List of users who can bypass this rule.
        :param pulumi.Input[_builtins.int] created: Timestamp when the rule was created.
        :param pulumi.Input[_builtins.int] created_by: ID of the user who created the rule.
        :param pulumi.Input[_builtins.str] description: Description of the rule.
        :param pulumi.Input[_builtins.str] identifier: Identifier of the rule.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RepoRuleBranchPatternArgs', 'RepoRuleBranchPatternArgsDict']]]] patterns: Pattern of branch to which rule will apply.
        :param pulumi.Input[Sequence[pulumi.Input[Union['RepoRuleBranchPolicyArgs', 'RepoRuleBranchPolicyArgsDict']]]] policies: Policies to be applied for this rule.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] repo_identifier: Repo identifier of the repository.
        :param pulumi.Input[_builtins.str] state: State of the rule (active, disable, monitor).
        :param pulumi.Input[_builtins.int] updated: Timestamp when the rule was updated.
        :param pulumi.Input[_builtins.int] updated_by: ID of the user who updated the rule.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RepoRuleBranchState.__new__(_RepoRuleBranchState)

        __props__.__dict__["bypasses"] = bypasses
        __props__.__dict__["created"] = created
        __props__.__dict__["created_by"] = created_by
        __props__.__dict__["description"] = description
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["patterns"] = patterns
        __props__.__dict__["policies"] = policies
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["repo_identifier"] = repo_identifier
        __props__.__dict__["state"] = state
        __props__.__dict__["updated"] = updated
        __props__.__dict__["updated_by"] = updated_by
        return RepoRuleBranch(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def bypasses(self) -> pulumi.Output[Sequence['outputs.RepoRuleBranchBypass']]:
        """
        List of users who can bypass this rule.
        """
        return pulumi.get(self, "bypasses")

    @_builtins.property
    @pulumi.getter
    def created(self) -> pulumi.Output[_builtins.int]:
        """
        Timestamp when the rule was created.
        """
        return pulumi.get(self, "created")

    @_builtins.property
    @pulumi.getter(name="createdBy")
    def created_by(self) -> pulumi.Output[_builtins.int]:
        """
        ID of the user who created the rule.
        """
        return pulumi.get(self, "created_by")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the rule.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Identifier of the rule.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter
    def patterns(self) -> pulumi.Output[Optional[Sequence['outputs.RepoRuleBranchPattern']]]:
        """
        Pattern of branch to which rule will apply.
        """
        return pulumi.get(self, "patterns")

    @_builtins.property
    @pulumi.getter
    def policies(self) -> pulumi.Output[Sequence['outputs.RepoRuleBranchPolicy']]:
        """
        Policies to be applied for this rule.
        """
        return pulumi.get(self, "policies")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="repoIdentifier")
    def repo_identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Repo identifier of the repository.
        """
        return pulumi.get(self, "repo_identifier")

    @_builtins.property
    @pulumi.getter
    def state(self) -> pulumi.Output[_builtins.str]:
        """
        State of the rule (active, disable, monitor).
        """
        return pulumi.get(self, "state")

    @_builtins.property
    @pulumi.getter
    def updated(self) -> pulumi.Output[_builtins.int]:
        """
        Timestamp when the rule was updated.
        """
        return pulumi.get(self, "updated")

    @_builtins.property
    @pulumi.getter(name="updatedBy")
    def updated_by(self) -> pulumi.Output[_builtins.int]:
        """
        ID of the user who updated the rule.
        """
        return pulumi.get(self, "updated_by")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetInfraVariableSetResult',
    'AwaitableGetInfraVariableSetResult',
    'get_infra_variable_set',
    'get_infra_variable_set_output',
]

@pulumi.output_type
class GetInfraVariableSetResult:
    """
    A collection of values returned by getInfraVariableSet.
    """
    def __init__(__self__, connectors=None, description=None, environment_variables=None, id=None, identifier=None, name=None, org_id=None, project_id=None, tags=None, terraform_variable_files=None, terraform_variables=None):
        if connectors and not isinstance(connectors, list):
            raise TypeError("Expected argument 'connectors' to be a list")
        pulumi.set(__self__, "connectors", connectors)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if environment_variables and not isinstance(environment_variables, list):
            raise TypeError("Expected argument 'environment_variables' to be a list")
        pulumi.set(__self__, "environment_variables", environment_variables)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if terraform_variable_files and not isinstance(terraform_variable_files, list):
            raise TypeError("Expected argument 'terraform_variable_files' to be a list")
        pulumi.set(__self__, "terraform_variable_files", terraform_variable_files)
        if terraform_variables and not isinstance(terraform_variables, list):
            raise TypeError("Expected argument 'terraform_variables' to be a list")
        pulumi.set(__self__, "terraform_variables", terraform_variables)

    @_builtins.property
    @pulumi.getter
    def connectors(self) -> Sequence['outputs.GetInfraVariableSetConnectorResult']:
        """
        Provider connectors configured on the Variable Set. Only one connector of a type is supported
        """
        return pulumi.get(self, "connectors")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="environmentVariables")
    def environment_variables(self) -> Sequence['outputs.GetInfraVariableSetEnvironmentVariableResult']:
        """
        Environment variables configured on the Variable Set
        """
        return pulumi.get(self, "environment_variables")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="terraformVariableFiles")
    def terraform_variable_files(self) -> Sequence['outputs.GetInfraVariableSetTerraformVariableFileResult']:
        return pulumi.get(self, "terraform_variable_files")

    @_builtins.property
    @pulumi.getter(name="terraformVariables")
    def terraform_variables(self) -> Sequence['outputs.GetInfraVariableSetTerraformVariableResult']:
        return pulumi.get(self, "terraform_variables")


class AwaitableGetInfraVariableSetResult(GetInfraVariableSetResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInfraVariableSetResult(
            connectors=self.connectors,
            description=self.description,
            environment_variables=self.environment_variables,
            id=self.id,
            identifier=self.identifier,
            name=self.name,
            org_id=self.org_id,
            project_id=self.project_id,
            tags=self.tags,
            terraform_variable_files=self.terraform_variable_files,
            terraform_variables=self.terraform_variables)


def get_infra_variable_set(connectors: Optional[Sequence[Union['GetInfraVariableSetConnectorArgs', 'GetInfraVariableSetConnectorArgsDict']]] = None,
                           environment_variables: Optional[Sequence[Union['GetInfraVariableSetEnvironmentVariableArgs', 'GetInfraVariableSetEnvironmentVariableArgsDict']]] = None,
                           identifier: Optional[_builtins.str] = None,
                           name: Optional[_builtins.str] = None,
                           org_id: Optional[_builtins.str] = None,
                           project_id: Optional[_builtins.str] = None,
                           terraform_variable_files: Optional[Sequence[Union['GetInfraVariableSetTerraformVariableFileArgs', 'GetInfraVariableSetTerraformVariableFileArgsDict']]] = None,
                           terraform_variables: Optional[Sequence[Union['GetInfraVariableSetTerraformVariableArgs', 'GetInfraVariableSetTerraformVariableArgsDict']]] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInfraVariableSetResult:
    """
    Data source for retrieving Variable Sets.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    test = harness.platform.get_infra_variable_set(identifier="identifier")
    testorg = harness.platform.get_infra_variable_set(identifier="identifier",
        org_id="someorg")
    testproj = harness.platform.get_infra_variable_set(identifier="identifier",
        org_id="someorg",
        project_id="someproj")
    ```


    :param Sequence[Union['GetInfraVariableSetConnectorArgs', 'GetInfraVariableSetConnectorArgsDict']] connectors: Provider connectors configured on the Variable Set. Only one connector of a type is supported
    :param Sequence[Union['GetInfraVariableSetEnvironmentVariableArgs', 'GetInfraVariableSetEnvironmentVariableArgsDict']] environment_variables: Environment variables configured on the Variable Set
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['connectors'] = connectors
    __args__['environmentVariables'] = environment_variables
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['terraformVariableFiles'] = terraform_variable_files
    __args__['terraformVariables'] = terraform_variables
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getInfraVariableSet:getInfraVariableSet', __args__, opts=opts, typ=GetInfraVariableSetResult).value

    return AwaitableGetInfraVariableSetResult(
        connectors=pulumi.get(__ret__, 'connectors'),
        description=pulumi.get(__ret__, 'description'),
        environment_variables=pulumi.get(__ret__, 'environment_variables'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        project_id=pulumi.get(__ret__, 'project_id'),
        tags=pulumi.get(__ret__, 'tags'),
        terraform_variable_files=pulumi.get(__ret__, 'terraform_variable_files'),
        terraform_variables=pulumi.get(__ret__, 'terraform_variables'))
def get_infra_variable_set_output(connectors: Optional[pulumi.Input[Optional[Sequence[Union['GetInfraVariableSetConnectorArgs', 'GetInfraVariableSetConnectorArgsDict']]]]] = None,
                                  environment_variables: Optional[pulumi.Input[Optional[Sequence[Union['GetInfraVariableSetEnvironmentVariableArgs', 'GetInfraVariableSetEnvironmentVariableArgsDict']]]]] = None,
                                  identifier: Optional[pulumi.Input[_builtins.str]] = None,
                                  name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                  org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                  project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                  terraform_variable_files: Optional[pulumi.Input[Optional[Sequence[Union['GetInfraVariableSetTerraformVariableFileArgs', 'GetInfraVariableSetTerraformVariableFileArgsDict']]]]] = None,
                                  terraform_variables: Optional[pulumi.Input[Optional[Sequence[Union['GetInfraVariableSetTerraformVariableArgs', 'GetInfraVariableSetTerraformVariableArgsDict']]]]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetInfraVariableSetResult]:
    """
    Data source for retrieving Variable Sets.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    test = harness.platform.get_infra_variable_set(identifier="identifier")
    testorg = harness.platform.get_infra_variable_set(identifier="identifier",
        org_id="someorg")
    testproj = harness.platform.get_infra_variable_set(identifier="identifier",
        org_id="someorg",
        project_id="someproj")
    ```


    :param Sequence[Union['GetInfraVariableSetConnectorArgs', 'GetInfraVariableSetConnectorArgsDict']] connectors: Provider connectors configured on the Variable Set. Only one connector of a type is supported
    :param Sequence[Union['GetInfraVariableSetEnvironmentVariableArgs', 'GetInfraVariableSetEnvironmentVariableArgsDict']] environment_variables: Environment variables configured on the Variable Set
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['connectors'] = connectors
    __args__['environmentVariables'] = environment_variables
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    __args__['terraformVariableFiles'] = terraform_variable_files
    __args__['terraformVariables'] = terraform_variables
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getInfraVariableSet:getInfraVariableSet', __args__, opts=opts, typ=GetInfraVariableSetResult)
    return __ret__.apply(lambda __response__: GetInfraVariableSetResult(
        connectors=pulumi.get(__response__, 'connectors'),
        description=pulumi.get(__response__, 'description'),
        environment_variables=pulumi.get(__response__, 'environment_variables'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        project_id=pulumi.get(__response__, 'project_id'),
        tags=pulumi.get(__response__, 'tags'),
        terraform_variable_files=pulumi.get(__response__, 'terraform_variable_files'),
        terraform_variables=pulumi.get(__response__, 'terraform_variables')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ConnectorCustomSecretManagerArgs', 'ConnectorCustomSecretManager']

@pulumi.input_type
class ConnectorCustomSecretManagerArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 template_ref: pulumi.Input[_builtins.str],
                 version_label: pulumi.Input[_builtins.str],
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 on_delegate: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ssh_secret_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_host: Optional[pulumi.Input[_builtins.str]] = None,
                 template_inputs: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectorCustomSecretManagerTemplateInputArgs']]]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 working_directory: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a ConnectorCustomSecretManager resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Tags to filter delegates for connection.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] ssh_secret_ref: SSH secret reference for the custom secrets manager, required if 'on_delegate' is false.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] target_host: Host where the custom secrets manager is located, required if 'on_delegate' is false.
        :param pulumi.Input[_builtins.str] working_directory: The working directory for operations, required if 'on_delegate' is false.
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "template_ref", template_ref)
        pulumi.set(__self__, "version_label", version_label)
        if delegate_selectors is not None:
            pulumi.set(__self__, "delegate_selectors", delegate_selectors)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if on_delegate is not None:
            pulumi.set(__self__, "on_delegate", on_delegate)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if ssh_secret_ref is not None:
            pulumi.set(__self__, "ssh_secret_ref", ssh_secret_ref)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if target_host is not None:
            pulumi.set(__self__, "target_host", target_host)
        if template_inputs is not None:
            pulumi.set(__self__, "template_inputs", template_inputs)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if working_directory is not None:
            pulumi.set(__self__, "working_directory", working_directory)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="templateRef")
    def template_ref(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "template_ref")

    @template_ref.setter
    def template_ref(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "template_ref", value)

    @_builtins.property
    @pulumi.getter(name="versionLabel")
    def version_label(self) -> pulumi.Input[_builtins.str]:
        return pulumi.get(self, "version_label")

    @version_label.setter
    def version_label(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "version_label", value)

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to filter delegates for connection.
        """
        return pulumi.get(self, "delegate_selectors")

    @delegate_selectors.setter
    def delegate_selectors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "delegate_selectors", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="onDelegate")
    def on_delegate(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "on_delegate")

    @on_delegate.setter
    def on_delegate(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "on_delegate", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="sshSecretRef")
    def ssh_secret_ref(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        SSH secret reference for the custom secrets manager, required if 'on_delegate' is false.
        """
        return pulumi.get(self, "ssh_secret_ref")

    @ssh_secret_ref.setter
    def ssh_secret_ref(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ssh_secret_ref", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="targetHost")
    def target_host(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Host where the custom secrets manager is located, required if 'on_delegate' is false.
        """
        return pulumi.get(self, "target_host")

    @target_host.setter
    def target_host(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_host", value)

    @_builtins.property
    @pulumi.getter(name="templateInputs")
    def template_inputs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConnectorCustomSecretManagerTemplateInputArgs']]]]:
        return pulumi.get(self, "template_inputs")

    @template_inputs.setter
    def template_inputs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectorCustomSecretManagerTemplateInputArgs']]]]):
        pulumi.set(self, "template_inputs", value)

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "timeout", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="workingDirectory")
    def working_directory(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The working directory for operations, required if 'on_delegate' is false.
        """
        return pulumi.get(self, "working_directory")

    @working_directory.setter
    def working_directory(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "working_directory", value)


@pulumi.input_type
class _ConnectorCustomSecretManagerState:
    def __init__(__self__, *,
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 on_delegate: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ssh_secret_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_host: Optional[pulumi.Input[_builtins.str]] = None,
                 template_inputs: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectorCustomSecretManagerTemplateInputArgs']]]] = None,
                 template_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 version_label: Optional[pulumi.Input[_builtins.str]] = None,
                 working_directory: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering ConnectorCustomSecretManager resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Tags to filter delegates for connection.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] ssh_secret_ref: SSH secret reference for the custom secrets manager, required if 'on_delegate' is false.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] target_host: Host where the custom secrets manager is located, required if 'on_delegate' is false.
        :param pulumi.Input[_builtins.str] working_directory: The working directory for operations, required if 'on_delegate' is false.
        """
        if delegate_selectors is not None:
            pulumi.set(__self__, "delegate_selectors", delegate_selectors)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if on_delegate is not None:
            pulumi.set(__self__, "on_delegate", on_delegate)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if ssh_secret_ref is not None:
            pulumi.set(__self__, "ssh_secret_ref", ssh_secret_ref)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if target_host is not None:
            pulumi.set(__self__, "target_host", target_host)
        if template_inputs is not None:
            pulumi.set(__self__, "template_inputs", template_inputs)
        if template_ref is not None:
            pulumi.set(__self__, "template_ref", template_ref)
        if timeout is not None:
            pulumi.set(__self__, "timeout", timeout)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if version_label is not None:
            pulumi.set(__self__, "version_label", version_label)
        if working_directory is not None:
            pulumi.set(__self__, "working_directory", working_directory)

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to filter delegates for connection.
        """
        return pulumi.get(self, "delegate_selectors")

    @delegate_selectors.setter
    def delegate_selectors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "delegate_selectors", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="onDelegate")
    def on_delegate(self) -> Optional[pulumi.Input[_builtins.bool]]:
        return pulumi.get(self, "on_delegate")

    @on_delegate.setter
    def on_delegate(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "on_delegate", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="sshSecretRef")
    def ssh_secret_ref(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        SSH secret reference for the custom secrets manager, required if 'on_delegate' is false.
        """
        return pulumi.get(self, "ssh_secret_ref")

    @ssh_secret_ref.setter
    def ssh_secret_ref(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "ssh_secret_ref", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="targetHost")
    def target_host(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Host where the custom secrets manager is located, required if 'on_delegate' is false.
        """
        return pulumi.get(self, "target_host")

    @target_host.setter
    def target_host(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "target_host", value)

    @_builtins.property
    @pulumi.getter(name="templateInputs")
    def template_inputs(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ConnectorCustomSecretManagerTemplateInputArgs']]]]:
        return pulumi.get(self, "template_inputs")

    @template_inputs.setter
    def template_inputs(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ConnectorCustomSecretManagerTemplateInputArgs']]]]):
        pulumi.set(self, "template_inputs", value)

    @_builtins.property
    @pulumi.getter(name="templateRef")
    def template_ref(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "template_ref")

    @template_ref.setter
    def template_ref(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "template_ref", value)

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> Optional[pulumi.Input[_builtins.int]]:
        return pulumi.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "timeout", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="versionLabel")
    def version_label(self) -> Optional[pulumi.Input[_builtins.str]]:
        return pulumi.get(self, "version_label")

    @version_label.setter
    def version_label(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "version_label", value)

    @_builtins.property
    @pulumi.getter(name="workingDirectory")
    def working_directory(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The working directory for operations, required if 'on_delegate' is false.
        """
        return pulumi.get(self, "working_directory")

    @working_directory.setter
    def working_directory(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "working_directory", value)


@pulumi.type_token("harness:platform/connectorCustomSecretManager:ConnectorCustomSecretManager")
class ConnectorCustomSecretManager(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 on_delegate: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ssh_secret_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_host: Optional[pulumi.Input[_builtins.str]] = None,
                 template_inputs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectorCustomSecretManagerTemplateInputArgs', 'ConnectorCustomSecretManagerTemplateInputArgsDict']]]]] = None,
                 template_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 version_label: Optional[pulumi.Input[_builtins.str]] = None,
                 working_directory: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a Custom Secrets Manager (CSM) connector.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Tags to filter delegates for connection.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] ssh_secret_ref: SSH secret reference for the custom secrets manager, required if 'on_delegate' is false.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] target_host: Host where the custom secrets manager is located, required if 'on_delegate' is false.
        :param pulumi.Input[_builtins.str] working_directory: The working directory for operations, required if 'on_delegate' is false.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ConnectorCustomSecretManagerArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Custom Secrets Manager (CSM) connector.

        :param str resource_name: The name of the resource.
        :param ConnectorCustomSecretManagerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ConnectorCustomSecretManagerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 on_delegate: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 ssh_secret_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 target_host: Optional[pulumi.Input[_builtins.str]] = None,
                 template_inputs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectorCustomSecretManagerTemplateInputArgs', 'ConnectorCustomSecretManagerTemplateInputArgsDict']]]]] = None,
                 template_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 timeout: Optional[pulumi.Input[_builtins.int]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 version_label: Optional[pulumi.Input[_builtins.str]] = None,
                 working_directory: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ConnectorCustomSecretManagerArgs.__new__(ConnectorCustomSecretManagerArgs)

            __props__.__dict__["delegate_selectors"] = delegate_selectors
            __props__.__dict__["description"] = description
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["name"] = name
            __props__.__dict__["on_delegate"] = on_delegate
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["ssh_secret_ref"] = ssh_secret_ref
            __props__.__dict__["tags"] = tags
            __props__.__dict__["target_host"] = target_host
            __props__.__dict__["template_inputs"] = template_inputs
            if template_ref is None and not opts.urn:
                raise TypeError("Missing required property 'template_ref'")
            __props__.__dict__["template_ref"] = template_ref
            __props__.__dict__["timeout"] = timeout
            __props__.__dict__["type"] = type
            if version_label is None and not opts.urn:
                raise TypeError("Missing required property 'version_label'")
            __props__.__dict__["version_label"] = version_label
            __props__.__dict__["working_directory"] = working_directory
        super(ConnectorCustomSecretManager, __self__).__init__(
            'harness:platform/connectorCustomSecretManager:ConnectorCustomSecretManager',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            on_delegate: Optional[pulumi.Input[_builtins.bool]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            ssh_secret_ref: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            target_host: Optional[pulumi.Input[_builtins.str]] = None,
            template_inputs: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ConnectorCustomSecretManagerTemplateInputArgs', 'ConnectorCustomSecretManagerTemplateInputArgsDict']]]]] = None,
            template_ref: Optional[pulumi.Input[_builtins.str]] = None,
            timeout: Optional[pulumi.Input[_builtins.int]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None,
            version_label: Optional[pulumi.Input[_builtins.str]] = None,
            working_directory: Optional[pulumi.Input[_builtins.str]] = None) -> 'ConnectorCustomSecretManager':
        """
        Get an existing ConnectorCustomSecretManager resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Tags to filter delegates for connection.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] ssh_secret_ref: SSH secret reference for the custom secrets manager, required if 'on_delegate' is false.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] target_host: Host where the custom secrets manager is located, required if 'on_delegate' is false.
        :param pulumi.Input[_builtins.str] working_directory: The working directory for operations, required if 'on_delegate' is false.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ConnectorCustomSecretManagerState.__new__(_ConnectorCustomSecretManagerState)

        __props__.__dict__["delegate_selectors"] = delegate_selectors
        __props__.__dict__["description"] = description
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["name"] = name
        __props__.__dict__["on_delegate"] = on_delegate
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["ssh_secret_ref"] = ssh_secret_ref
        __props__.__dict__["tags"] = tags
        __props__.__dict__["target_host"] = target_host
        __props__.__dict__["template_inputs"] = template_inputs
        __props__.__dict__["template_ref"] = template_ref
        __props__.__dict__["timeout"] = timeout
        __props__.__dict__["type"] = type
        __props__.__dict__["version_label"] = version_label
        __props__.__dict__["working_directory"] = working_directory
        return ConnectorCustomSecretManager(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to filter delegates for connection.
        """
        return pulumi.get(self, "delegate_selectors")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="onDelegate")
    def on_delegate(self) -> pulumi.Output[Optional[_builtins.bool]]:
        return pulumi.get(self, "on_delegate")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="sshSecretRef")
    def ssh_secret_ref(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        SSH secret reference for the custom secrets manager, required if 'on_delegate' is false.
        """
        return pulumi.get(self, "ssh_secret_ref")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="targetHost")
    def target_host(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Host where the custom secrets manager is located, required if 'on_delegate' is false.
        """
        return pulumi.get(self, "target_host")

    @_builtins.property
    @pulumi.getter(name="templateInputs")
    def template_inputs(self) -> pulumi.Output[Optional[Sequence['outputs.ConnectorCustomSecretManagerTemplateInput']]]:
        return pulumi.get(self, "template_inputs")

    @_builtins.property
    @pulumi.getter(name="templateRef")
    def template_ref(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "template_ref")

    @_builtins.property
    @pulumi.getter
    def timeout(self) -> pulumi.Output[Optional[_builtins.int]]:
        return pulumi.get(self, "timeout")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[Optional[_builtins.str]]:
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="versionLabel")
    def version_label(self) -> pulumi.Output[_builtins.str]:
        return pulumi.get(self, "version_label")

    @_builtins.property
    @pulumi.getter(name="workingDirectory")
    def working_directory(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The working directory for operations, required if 'on_delegate' is false.
        """
        return pulumi.get(self, "working_directory")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = [
    'GetYamlConfigResult',
    'AwaitableGetYamlConfigResult',
    'get_yaml_config',
    'get_yaml_config_output',
]

@pulumi.output_type
class GetYamlConfigResult:
    """
    A collection of values returned by getYamlConfig.
    """
    def __init__(__self__, app_id=None, content=None, id=None, name=None, path=None):
        if app_id and not isinstance(app_id, str):
            raise TypeError("Expected argument 'app_id' to be a str")
        pulumi.set(__self__, "app_id", app_id)
        if content and not isinstance(content, str):
            raise TypeError("Expected argument 'content' to be a str")
        pulumi.set(__self__, "content", content)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if path and not isinstance(path, str):
            raise TypeError("Expected argument 'path' to be a str")
        pulumi.set(__self__, "path", path)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the application. This is not required for account level resources (i.e. cloud providers, connectors, etc.).
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter
    def content(self) -> _builtins.str:
        """
        Content of the yaml file.
        """
        return pulumi.get(self, "content")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Unique identifier of the yaml resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def name(self) -> _builtins.str:
        """
        Name of the yaml resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def path(self) -> _builtins.str:
        """
        Path to the yaml file.
        """
        return pulumi.get(self, "path")


class AwaitableGetYamlConfigResult(GetYamlConfigResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetYamlConfigResult(
            app_id=self.app_id,
            content=self.content,
            id=self.id,
            name=self.name,
            path=self.path)


def get_yaml_config(app_id: Optional[_builtins.str] = None,
                    path: Optional[_builtins.str] = None,
                    opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetYamlConfigResult:
    """
    Data source for retrieving a yaml config.


    :param _builtins.str app_id: Unique identifier of the application. This is not required for account level resources (i.e. cloud providers, connectors, etc.).
    :param _builtins.str path: Path to the yaml file.
    """
    __args__ = dict()
    __args__['appId'] = app_id
    __args__['path'] = path
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:index/getYamlConfig:getYamlConfig', __args__, opts=opts, typ=GetYamlConfigResult).value

    return AwaitableGetYamlConfigResult(
        app_id=pulumi.get(__ret__, 'app_id'),
        content=pulumi.get(__ret__, 'content'),
        id=pulumi.get(__ret__, 'id'),
        name=pulumi.get(__ret__, 'name'),
        path=pulumi.get(__ret__, 'path'))
def get_yaml_config_output(app_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                           path: Optional[pulumi.Input[_builtins.str]] = None,
                           opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetYamlConfigResult]:
    """
    Data source for retrieving a yaml config.


    :param _builtins.str app_id: Unique identifier of the application. This is not required for account level resources (i.e. cloud providers, connectors, etc.).
    :param _builtins.str path: Path to the yaml file.
    """
    __args__ = dict()
    __args__['appId'] = app_id
    __args__['path'] = path
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:index/getYamlConfig:getYamlConfig', __args__, opts=opts, typ=GetYamlConfigResult)
    return __ret__.apply(lambda __response__: GetYamlConfigResult(
        app_id=pulumi.get(__response__, 'app_id'),
        content=pulumi.get(__response__, 'content'),
        id=pulumi.get(__response__, 'id'),
        name=pulumi.get(__response__, 'name'),
        path=pulumi.get(__response__, 'path')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['PolicyArgs', 'Policy']

@pulumi.input_type
class PolicyArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 rego: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_base_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 git_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 git_commit_msg: Optional[pulumi.Input[_builtins.str]] = None,
                 git_commit_sha: Optional[pulumi.Input[_builtins.str]] = None,
                 git_connector_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 git_file_id: Optional[pulumi.Input[_builtins.str]] = None,
                 git_import: Optional[pulumi.Input[_builtins.bool]] = None,
                 git_is_new_branch: Optional[pulumi.Input[_builtins.bool]] = None,
                 git_path: Optional[pulumi.Input[_builtins.str]] = None,
                 git_repo: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a Policy resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] rego: Rego code for the policy.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] git_base_branch: Base branch for the new git branch.
        :param pulumi.Input[_builtins.str] git_branch: Git branch for the policy.
        :param pulumi.Input[_builtins.str] git_commit_msg: Git commit message for the policy.
        :param pulumi.Input[_builtins.str] git_commit_sha: The existing commit sha of the file being updated
        :param pulumi.Input[_builtins.str] git_connector_ref: Git connector reference for the policy.
        :param pulumi.Input[_builtins.str] git_file_id: The existing file id of the file being updated, not required for bitbucket files
        :param pulumi.Input[_builtins.bool] git_import: Flag to import the policy from git.
        :param pulumi.Input[_builtins.bool] git_is_new_branch: Flag to create a new branch for the policy.
        :param pulumi.Input[_builtins.str] git_path: Git path for the policy.
        :param pulumi.Input[_builtins.str] git_repo: Git repository for the policy.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "rego", rego)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if git_base_branch is not None:
            pulumi.set(__self__, "git_base_branch", git_base_branch)
        if git_branch is not None:
            pulumi.set(__self__, "git_branch", git_branch)
        if git_commit_msg is not None:
            pulumi.set(__self__, "git_commit_msg", git_commit_msg)
        if git_commit_sha is not None:
            pulumi.set(__self__, "git_commit_sha", git_commit_sha)
        if git_connector_ref is not None:
            pulumi.set(__self__, "git_connector_ref", git_connector_ref)
        if git_file_id is not None:
            pulumi.set(__self__, "git_file_id", git_file_id)
        if git_import is not None:
            pulumi.set(__self__, "git_import", git_import)
        if git_is_new_branch is not None:
            pulumi.set(__self__, "git_is_new_branch", git_is_new_branch)
        if git_path is not None:
            pulumi.set(__self__, "git_path", git_path)
        if git_repo is not None:
            pulumi.set(__self__, "git_repo", git_repo)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def rego(self) -> pulumi.Input[_builtins.str]:
        """
        Rego code for the policy.
        """
        return pulumi.get(self, "rego")

    @rego.setter
    def rego(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "rego", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="gitBaseBranch")
    def git_base_branch(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Base branch for the new git branch.
        """
        return pulumi.get(self, "git_base_branch")

    @git_base_branch.setter
    def git_base_branch(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_base_branch", value)

    @_builtins.property
    @pulumi.getter(name="gitBranch")
    def git_branch(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Git branch for the policy.
        """
        return pulumi.get(self, "git_branch")

    @git_branch.setter
    def git_branch(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_branch", value)

    @_builtins.property
    @pulumi.getter(name="gitCommitMsg")
    def git_commit_msg(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Git commit message for the policy.
        """
        return pulumi.get(self, "git_commit_msg")

    @git_commit_msg.setter
    def git_commit_msg(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_commit_msg", value)

    @_builtins.property
    @pulumi.getter(name="gitCommitSha")
    def git_commit_sha(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The existing commit sha of the file being updated
        """
        return pulumi.get(self, "git_commit_sha")

    @git_commit_sha.setter
    def git_commit_sha(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_commit_sha", value)

    @_builtins.property
    @pulumi.getter(name="gitConnectorRef")
    def git_connector_ref(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Git connector reference for the policy.
        """
        return pulumi.get(self, "git_connector_ref")

    @git_connector_ref.setter
    def git_connector_ref(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_connector_ref", value)

    @_builtins.property
    @pulumi.getter(name="gitFileId")
    def git_file_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The existing file id of the file being updated, not required for bitbucket files
        """
        return pulumi.get(self, "git_file_id")

    @git_file_id.setter
    def git_file_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_file_id", value)

    @_builtins.property
    @pulumi.getter(name="gitImport")
    def git_import(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag to import the policy from git.
        """
        return pulumi.get(self, "git_import")

    @git_import.setter
    def git_import(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "git_import", value)

    @_builtins.property
    @pulumi.getter(name="gitIsNewBranch")
    def git_is_new_branch(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag to create a new branch for the policy.
        """
        return pulumi.get(self, "git_is_new_branch")

    @git_is_new_branch.setter
    def git_is_new_branch(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "git_is_new_branch", value)

    @_builtins.property
    @pulumi.getter(name="gitPath")
    def git_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Git path for the policy.
        """
        return pulumi.get(self, "git_path")

    @git_path.setter
    def git_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_path", value)

    @_builtins.property
    @pulumi.getter(name="gitRepo")
    def git_repo(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Git repository for the policy.
        """
        return pulumi.get(self, "git_repo")

    @git_repo.setter
    def git_repo(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_repo", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.input_type
class _PolicyState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_base_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 git_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 git_commit_msg: Optional[pulumi.Input[_builtins.str]] = None,
                 git_commit_sha: Optional[pulumi.Input[_builtins.str]] = None,
                 git_connector_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 git_file_id: Optional[pulumi.Input[_builtins.str]] = None,
                 git_import: Optional[pulumi.Input[_builtins.bool]] = None,
                 git_is_new_branch: Optional[pulumi.Input[_builtins.bool]] = None,
                 git_path: Optional[pulumi.Input[_builtins.str]] = None,
                 git_repo: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rego: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering Policy resources.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] git_base_branch: Base branch for the new git branch.
        :param pulumi.Input[_builtins.str] git_branch: Git branch for the policy.
        :param pulumi.Input[_builtins.str] git_commit_msg: Git commit message for the policy.
        :param pulumi.Input[_builtins.str] git_commit_sha: The existing commit sha of the file being updated
        :param pulumi.Input[_builtins.str] git_connector_ref: Git connector reference for the policy.
        :param pulumi.Input[_builtins.str] git_file_id: The existing file id of the file being updated, not required for bitbucket files
        :param pulumi.Input[_builtins.bool] git_import: Flag to import the policy from git.
        :param pulumi.Input[_builtins.bool] git_is_new_branch: Flag to create a new branch for the policy.
        :param pulumi.Input[_builtins.str] git_path: Git path for the policy.
        :param pulumi.Input[_builtins.str] git_repo: Git repository for the policy.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] rego: Rego code for the policy.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if git_base_branch is not None:
            pulumi.set(__self__, "git_base_branch", git_base_branch)
        if git_branch is not None:
            pulumi.set(__self__, "git_branch", git_branch)
        if git_commit_msg is not None:
            pulumi.set(__self__, "git_commit_msg", git_commit_msg)
        if git_commit_sha is not None:
            pulumi.set(__self__, "git_commit_sha", git_commit_sha)
        if git_connector_ref is not None:
            pulumi.set(__self__, "git_connector_ref", git_connector_ref)
        if git_file_id is not None:
            pulumi.set(__self__, "git_file_id", git_file_id)
        if git_import is not None:
            pulumi.set(__self__, "git_import", git_import)
        if git_is_new_branch is not None:
            pulumi.set(__self__, "git_is_new_branch", git_is_new_branch)
        if git_path is not None:
            pulumi.set(__self__, "git_path", git_path)
        if git_repo is not None:
            pulumi.set(__self__, "git_repo", git_repo)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if rego is not None:
            pulumi.set(__self__, "rego", rego)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="gitBaseBranch")
    def git_base_branch(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Base branch for the new git branch.
        """
        return pulumi.get(self, "git_base_branch")

    @git_base_branch.setter
    def git_base_branch(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_base_branch", value)

    @_builtins.property
    @pulumi.getter(name="gitBranch")
    def git_branch(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Git branch for the policy.
        """
        return pulumi.get(self, "git_branch")

    @git_branch.setter
    def git_branch(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_branch", value)

    @_builtins.property
    @pulumi.getter(name="gitCommitMsg")
    def git_commit_msg(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Git commit message for the policy.
        """
        return pulumi.get(self, "git_commit_msg")

    @git_commit_msg.setter
    def git_commit_msg(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_commit_msg", value)

    @_builtins.property
    @pulumi.getter(name="gitCommitSha")
    def git_commit_sha(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The existing commit sha of the file being updated
        """
        return pulumi.get(self, "git_commit_sha")

    @git_commit_sha.setter
    def git_commit_sha(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_commit_sha", value)

    @_builtins.property
    @pulumi.getter(name="gitConnectorRef")
    def git_connector_ref(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Git connector reference for the policy.
        """
        return pulumi.get(self, "git_connector_ref")

    @git_connector_ref.setter
    def git_connector_ref(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_connector_ref", value)

    @_builtins.property
    @pulumi.getter(name="gitFileId")
    def git_file_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The existing file id of the file being updated, not required for bitbucket files
        """
        return pulumi.get(self, "git_file_id")

    @git_file_id.setter
    def git_file_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_file_id", value)

    @_builtins.property
    @pulumi.getter(name="gitImport")
    def git_import(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag to import the policy from git.
        """
        return pulumi.get(self, "git_import")

    @git_import.setter
    def git_import(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "git_import", value)

    @_builtins.property
    @pulumi.getter(name="gitIsNewBranch")
    def git_is_new_branch(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Flag to create a new branch for the policy.
        """
        return pulumi.get(self, "git_is_new_branch")

    @git_is_new_branch.setter
    def git_is_new_branch(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "git_is_new_branch", value)

    @_builtins.property
    @pulumi.getter(name="gitPath")
    def git_path(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Git path for the policy.
        """
        return pulumi.get(self, "git_path")

    @git_path.setter
    def git_path(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_path", value)

    @_builtins.property
    @pulumi.getter(name="gitRepo")
    def git_repo(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Git repository for the policy.
        """
        return pulumi.get(self, "git_repo")

    @git_repo.setter
    def git_repo(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "git_repo", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def rego(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Rego code for the policy.
        """
        return pulumi.get(self, "rego")

    @rego.setter
    def rego(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "rego", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)


@pulumi.type_token("harness:platform/policy:Policy")
class Policy(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_base_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 git_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 git_commit_msg: Optional[pulumi.Input[_builtins.str]] = None,
                 git_commit_sha: Optional[pulumi.Input[_builtins.str]] = None,
                 git_connector_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 git_file_id: Optional[pulumi.Input[_builtins.str]] = None,
                 git_import: Optional[pulumi.Input[_builtins.bool]] = None,
                 git_is_new_branch: Optional[pulumi.Input[_builtins.bool]] = None,
                 git_path: Optional[pulumi.Input[_builtins.str]] = None,
                 git_repo: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rego: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for creating a Harness Policy.

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the organization id

        ```sh
        $ pulumi import harness:platform/policy:Policy example <organization_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] git_base_branch: Base branch for the new git branch.
        :param pulumi.Input[_builtins.str] git_branch: Git branch for the policy.
        :param pulumi.Input[_builtins.str] git_commit_msg: Git commit message for the policy.
        :param pulumi.Input[_builtins.str] git_commit_sha: The existing commit sha of the file being updated
        :param pulumi.Input[_builtins.str] git_connector_ref: Git connector reference for the policy.
        :param pulumi.Input[_builtins.str] git_file_id: The existing file id of the file being updated, not required for bitbucket files
        :param pulumi.Input[_builtins.bool] git_import: Flag to import the policy from git.
        :param pulumi.Input[_builtins.bool] git_is_new_branch: Flag to create a new branch for the policy.
        :param pulumi.Input[_builtins.str] git_path: Git path for the policy.
        :param pulumi.Input[_builtins.str] git_repo: Git repository for the policy.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] rego: Rego code for the policy.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PolicyArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness Policy.

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the organization id

        ```sh
        $ pulumi import harness:platform/policy:Policy example <organization_id>
        ```

        :param str resource_name: The name of the resource.
        :param PolicyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PolicyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 git_base_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 git_branch: Optional[pulumi.Input[_builtins.str]] = None,
                 git_commit_msg: Optional[pulumi.Input[_builtins.str]] = None,
                 git_commit_sha: Optional[pulumi.Input[_builtins.str]] = None,
                 git_connector_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 git_file_id: Optional[pulumi.Input[_builtins.str]] = None,
                 git_import: Optional[pulumi.Input[_builtins.bool]] = None,
                 git_is_new_branch: Optional[pulumi.Input[_builtins.bool]] = None,
                 git_path: Optional[pulumi.Input[_builtins.str]] = None,
                 git_repo: Optional[pulumi.Input[_builtins.str]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 rego: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PolicyArgs.__new__(PolicyArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["git_base_branch"] = git_base_branch
            __props__.__dict__["git_branch"] = git_branch
            __props__.__dict__["git_commit_msg"] = git_commit_msg
            __props__.__dict__["git_commit_sha"] = git_commit_sha
            __props__.__dict__["git_connector_ref"] = git_connector_ref
            __props__.__dict__["git_file_id"] = git_file_id
            __props__.__dict__["git_import"] = git_import
            __props__.__dict__["git_is_new_branch"] = git_is_new_branch
            __props__.__dict__["git_path"] = git_path
            __props__.__dict__["git_repo"] = git_repo
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            if rego is None and not opts.urn:
                raise TypeError("Missing required property 'rego'")
            __props__.__dict__["rego"] = rego
            __props__.__dict__["tags"] = tags
        super(Policy, __self__).__init__(
            'harness:platform/policy:Policy',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            git_base_branch: Optional[pulumi.Input[_builtins.str]] = None,
            git_branch: Optional[pulumi.Input[_builtins.str]] = None,
            git_commit_msg: Optional[pulumi.Input[_builtins.str]] = None,
            git_commit_sha: Optional[pulumi.Input[_builtins.str]] = None,
            git_connector_ref: Optional[pulumi.Input[_builtins.str]] = None,
            git_file_id: Optional[pulumi.Input[_builtins.str]] = None,
            git_import: Optional[pulumi.Input[_builtins.bool]] = None,
            git_is_new_branch: Optional[pulumi.Input[_builtins.bool]] = None,
            git_path: Optional[pulumi.Input[_builtins.str]] = None,
            git_repo: Optional[pulumi.Input[_builtins.str]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            rego: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'Policy':
        """
        Get an existing Policy resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[_builtins.str] git_base_branch: Base branch for the new git branch.
        :param pulumi.Input[_builtins.str] git_branch: Git branch for the policy.
        :param pulumi.Input[_builtins.str] git_commit_msg: Git commit message for the policy.
        :param pulumi.Input[_builtins.str] git_commit_sha: The existing commit sha of the file being updated
        :param pulumi.Input[_builtins.str] git_connector_ref: Git connector reference for the policy.
        :param pulumi.Input[_builtins.str] git_file_id: The existing file id of the file being updated, not required for bitbucket files
        :param pulumi.Input[_builtins.bool] git_import: Flag to import the policy from git.
        :param pulumi.Input[_builtins.bool] git_is_new_branch: Flag to create a new branch for the policy.
        :param pulumi.Input[_builtins.str] git_path: Git path for the policy.
        :param pulumi.Input[_builtins.str] git_repo: Git repository for the policy.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[_builtins.str] rego: Rego code for the policy.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PolicyState.__new__(_PolicyState)

        __props__.__dict__["description"] = description
        __props__.__dict__["git_base_branch"] = git_base_branch
        __props__.__dict__["git_branch"] = git_branch
        __props__.__dict__["git_commit_msg"] = git_commit_msg
        __props__.__dict__["git_commit_sha"] = git_commit_sha
        __props__.__dict__["git_connector_ref"] = git_connector_ref
        __props__.__dict__["git_file_id"] = git_file_id
        __props__.__dict__["git_import"] = git_import
        __props__.__dict__["git_is_new_branch"] = git_is_new_branch
        __props__.__dict__["git_path"] = git_path
        __props__.__dict__["git_repo"] = git_repo
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["rego"] = rego
        __props__.__dict__["tags"] = tags
        return Policy(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="gitBaseBranch")
    def git_base_branch(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Base branch for the new git branch.
        """
        return pulumi.get(self, "git_base_branch")

    @_builtins.property
    @pulumi.getter(name="gitBranch")
    def git_branch(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Git branch for the policy.
        """
        return pulumi.get(self, "git_branch")

    @_builtins.property
    @pulumi.getter(name="gitCommitMsg")
    def git_commit_msg(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Git commit message for the policy.
        """
        return pulumi.get(self, "git_commit_msg")

    @_builtins.property
    @pulumi.getter(name="gitCommitSha")
    def git_commit_sha(self) -> pulumi.Output[_builtins.str]:
        """
        The existing commit sha of the file being updated
        """
        return pulumi.get(self, "git_commit_sha")

    @_builtins.property
    @pulumi.getter(name="gitConnectorRef")
    def git_connector_ref(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Git connector reference for the policy.
        """
        return pulumi.get(self, "git_connector_ref")

    @_builtins.property
    @pulumi.getter(name="gitFileId")
    def git_file_id(self) -> pulumi.Output[_builtins.str]:
        """
        The existing file id of the file being updated, not required for bitbucket files
        """
        return pulumi.get(self, "git_file_id")

    @_builtins.property
    @pulumi.getter(name="gitImport")
    def git_import(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Flag to import the policy from git.
        """
        return pulumi.get(self, "git_import")

    @_builtins.property
    @pulumi.getter(name="gitIsNewBranch")
    def git_is_new_branch(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Flag to create a new branch for the policy.
        """
        return pulumi.get(self, "git_is_new_branch")

    @_builtins.property
    @pulumi.getter(name="gitPath")
    def git_path(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Git path for the policy.
        """
        return pulumi.get(self, "git_path")

    @_builtins.property
    @pulumi.getter(name="gitRepo")
    def git_repo(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Git repository for the policy.
        """
        return pulumi.get(self, "git_repo")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def rego(self) -> pulumi.Output[_builtins.str]:
        """
        Rego code for the policy.
        """
        return pulumi.get(self, "rego")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetFileStoreFileResult',
    'AwaitableGetFileStoreFileResult',
    'get_file_store_file',
    'get_file_store_file_output',
]

@pulumi.output_type
class GetFileStoreFileResult:
    """
    A collection of values returned by getFileStoreFile.
    """
    def __init__(__self__, content=None, created_bies=None, description=None, file_content_path=None, file_usage=None, id=None, identifier=None, last_modified_at=None, last_modified_bies=None, mime_type=None, name=None, org_id=None, parent_identifier=None, path=None, project_id=None, tags=None):
        if content and not isinstance(content, str):
            raise TypeError("Expected argument 'content' to be a str")
        pulumi.set(__self__, "content", content)
        if created_bies and not isinstance(created_bies, list):
            raise TypeError("Expected argument 'created_bies' to be a list")
        pulumi.set(__self__, "created_bies", created_bies)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if file_content_path and not isinstance(file_content_path, str):
            raise TypeError("Expected argument 'file_content_path' to be a str")
        pulumi.set(__self__, "file_content_path", file_content_path)
        if file_usage and not isinstance(file_usage, str):
            raise TypeError("Expected argument 'file_usage' to be a str")
        pulumi.set(__self__, "file_usage", file_usage)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if last_modified_at and not isinstance(last_modified_at, int):
            raise TypeError("Expected argument 'last_modified_at' to be a int")
        pulumi.set(__self__, "last_modified_at", last_modified_at)
        if last_modified_bies and not isinstance(last_modified_bies, list):
            raise TypeError("Expected argument 'last_modified_bies' to be a list")
        pulumi.set(__self__, "last_modified_bies", last_modified_bies)
        if mime_type and not isinstance(mime_type, str):
            raise TypeError("Expected argument 'mime_type' to be a str")
        pulumi.set(__self__, "mime_type", mime_type)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if org_id and not isinstance(org_id, str):
            raise TypeError("Expected argument 'org_id' to be a str")
        pulumi.set(__self__, "org_id", org_id)
        if parent_identifier and not isinstance(parent_identifier, str):
            raise TypeError("Expected argument 'parent_identifier' to be a str")
        pulumi.set(__self__, "parent_identifier", parent_identifier)
        if path and not isinstance(path, str):
            raise TypeError("Expected argument 'path' to be a str")
        pulumi.set(__self__, "path", path)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)

    @_builtins.property
    @pulumi.getter
    def content(self) -> _builtins.str:
        """
        File content stored on Harness File Store
        """
        return pulumi.get(self, "content")

    @_builtins.property
    @pulumi.getter(name="createdBies")
    def created_bies(self) -> Sequence['outputs.GetFileStoreFileCreatedByResult']:
        """
        Created by
        """
        return pulumi.get(self, "created_bies")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="fileContentPath")
    def file_content_path(self) -> _builtins.str:
        """
        File content path to be upladed on Harness File Store
        """
        return pulumi.get(self, "file_content_path")

    @_builtins.property
    @pulumi.getter(name="fileUsage")
    def file_usage(self) -> _builtins.str:
        """
        File usage. Valid options are MANIFEST_FILE, CONFIG, SCRIPT
        """
        return pulumi.get(self, "file_usage")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> _builtins.str:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="lastModifiedAt")
    def last_modified_at(self) -> _builtins.int:
        """
        Last modified at
        """
        return pulumi.get(self, "last_modified_at")

    @_builtins.property
    @pulumi.getter(name="lastModifiedBies")
    def last_modified_bies(self) -> Sequence['outputs.GetFileStoreFileLastModifiedByResult']:
        """
        Last modified by
        """
        return pulumi.get(self, "last_modified_bies")

    @_builtins.property
    @pulumi.getter(name="mimeType")
    def mime_type(self) -> _builtins.str:
        """
        File mime type
        """
        return pulumi.get(self, "mime_type")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="parentIdentifier")
    def parent_identifier(self) -> _builtins.str:
        """
        File parent identifier on Harness File Store
        """
        return pulumi.get(self, "parent_identifier")

    @_builtins.property
    @pulumi.getter
    def path(self) -> _builtins.str:
        """
        Harness File Store file path
        """
        return pulumi.get(self, "path")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")


class AwaitableGetFileStoreFileResult(GetFileStoreFileResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetFileStoreFileResult(
            content=self.content,
            created_bies=self.created_bies,
            description=self.description,
            file_content_path=self.file_content_path,
            file_usage=self.file_usage,
            id=self.id,
            identifier=self.identifier,
            last_modified_at=self.last_modified_at,
            last_modified_bies=self.last_modified_bies,
            mime_type=self.mime_type,
            name=self.name,
            org_id=self.org_id,
            parent_identifier=self.parent_identifier,
            path=self.path,
            project_id=self.project_id,
            tags=self.tags)


def get_file_store_file(identifier: Optional[_builtins.str] = None,
                        name: Optional[_builtins.str] = None,
                        org_id: Optional[_builtins.str] = None,
                        project_id: Optional[_builtins.str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetFileStoreFileResult:
    """
    Data source for retrieving files.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_file_store_file(identifier="identifier")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getFileStoreFile:getFileStoreFile', __args__, opts=opts, typ=GetFileStoreFileResult).value

    return AwaitableGetFileStoreFileResult(
        content=pulumi.get(__ret__, 'content'),
        created_bies=pulumi.get(__ret__, 'created_bies'),
        description=pulumi.get(__ret__, 'description'),
        file_content_path=pulumi.get(__ret__, 'file_content_path'),
        file_usage=pulumi.get(__ret__, 'file_usage'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        last_modified_at=pulumi.get(__ret__, 'last_modified_at'),
        last_modified_bies=pulumi.get(__ret__, 'last_modified_bies'),
        mime_type=pulumi.get(__ret__, 'mime_type'),
        name=pulumi.get(__ret__, 'name'),
        org_id=pulumi.get(__ret__, 'org_id'),
        parent_identifier=pulumi.get(__ret__, 'parent_identifier'),
        path=pulumi.get(__ret__, 'path'),
        project_id=pulumi.get(__ret__, 'project_id'),
        tags=pulumi.get(__ret__, 'tags'))
def get_file_store_file_output(identifier: Optional[pulumi.Input[_builtins.str]] = None,
                               name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               org_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                               opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetFileStoreFileResult]:
    """
    Data source for retrieving files.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.platform.get_file_store_file(identifier="identifier")
    ```


    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    :param _builtins.str org_id: Unique identifier of the organization.
    :param _builtins.str project_id: Unique identifier of the project.
    """
    __args__ = dict()
    __args__['identifier'] = identifier
    __args__['name'] = name
    __args__['orgId'] = org_id
    __args__['projectId'] = project_id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getFileStoreFile:getFileStoreFile', __args__, opts=opts, typ=GetFileStoreFileResult)
    return __ret__.apply(lambda __response__: GetFileStoreFileResult(
        content=pulumi.get(__response__, 'content'),
        created_bies=pulumi.get(__response__, 'created_bies'),
        description=pulumi.get(__response__, 'description'),
        file_content_path=pulumi.get(__response__, 'file_content_path'),
        file_usage=pulumi.get(__response__, 'file_usage'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        last_modified_at=pulumi.get(__response__, 'last_modified_at'),
        last_modified_bies=pulumi.get(__response__, 'last_modified_bies'),
        mime_type=pulumi.get(__response__, 'mime_type'),
        name=pulumi.get(__response__, 'name'),
        org_id=pulumi.get(__response__, 'org_id'),
        parent_identifier=pulumi.get(__response__, 'parent_identifier'),
        path=pulumi.get(__response__, 'path'),
        project_id=pulumi.get(__response__, 'project_id'),
        tags=pulumi.get(__response__, 'tags')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetDashboardsResult',
    'AwaitableGetDashboardsResult',
    'get_dashboards',
    'get_dashboards_output',
]

@pulumi.output_type
class GetDashboardsResult:
    """
    A collection of values returned by getDashboards.
    """
    def __init__(__self__, created_at=None, dashboard_id=None, data_sources=None, description=None, folder_id=None, id=None, identifier=None, models=None, name=None, resource_identifier=None, tags=None, title=None, type=None, view_count=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if dashboard_id and not isinstance(dashboard_id, str):
            raise TypeError("Expected argument 'dashboard_id' to be a str")
        pulumi.set(__self__, "dashboard_id", dashboard_id)
        if data_sources and not isinstance(data_sources, list):
            raise TypeError("Expected argument 'data_sources' to be a list")
        pulumi.set(__self__, "data_sources", data_sources)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if folder_id and not isinstance(folder_id, str):
            raise TypeError("Expected argument 'folder_id' to be a str")
        pulumi.set(__self__, "folder_id", folder_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if identifier and not isinstance(identifier, str):
            raise TypeError("Expected argument 'identifier' to be a str")
        pulumi.set(__self__, "identifier", identifier)
        if models and not isinstance(models, list):
            raise TypeError("Expected argument 'models' to be a list")
        pulumi.set(__self__, "models", models)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if resource_identifier and not isinstance(resource_identifier, str):
            raise TypeError("Expected argument 'resource_identifier' to be a str")
        pulumi.set(__self__, "resource_identifier", resource_identifier)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if title and not isinstance(title, str):
            raise TypeError("Expected argument 'title' to be a str")
        pulumi.set(__self__, "title", title)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)
        if view_count and not isinstance(view_count, int):
            raise TypeError("Expected argument 'view_count' to be a int")
        pulumi.set(__self__, "view_count", view_count)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> _builtins.str:
        """
        Created at timestamp of the Dashboard.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="dashboardId")
    def dashboard_id(self) -> _builtins.str:
        """
        Unique identifier of the Dashboard.
        """
        return pulumi.get(self, "dashboard_id")

    @_builtins.property
    @pulumi.getter(name="dataSources")
    def data_sources(self) -> Sequence[_builtins.str]:
        """
        Data Sources within the Dashboard.
        """
        return pulumi.get(self, "data_sources")

    @_builtins.property
    @pulumi.getter
    def description(self) -> _builtins.str:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="folderId")
    def folder_id(self) -> _builtins.str:
        """
        Unique identifier of the Folder.
        """
        return pulumi.get(self, "folder_id")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        Identifier of the dashboard.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def models(self) -> Sequence[_builtins.str]:
        """
        Data Models within the Dashboard.
        """
        return pulumi.get(self, "models")

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="resourceIdentifier")
    def resource_identifier(self) -> _builtins.str:
        """
        Resource identifier of the dashboard.
        """
        return pulumi.get(self, "resource_identifier")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Sequence[_builtins.str]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def title(self) -> _builtins.str:
        """
        Title of the Dashboard.
        """
        return pulumi.get(self, "title")

    @_builtins.property
    @pulumi.getter
    def type(self) -> _builtins.str:
        """
        Resource identifier of the dashboard.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="viewCount")
    def view_count(self) -> _builtins.int:
        """
        View count of the dashboard.
        """
        return pulumi.get(self, "view_count")


class AwaitableGetDashboardsResult(GetDashboardsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDashboardsResult(
            created_at=self.created_at,
            dashboard_id=self.dashboard_id,
            data_sources=self.data_sources,
            description=self.description,
            folder_id=self.folder_id,
            id=self.id,
            identifier=self.identifier,
            models=self.models,
            name=self.name,
            resource_identifier=self.resource_identifier,
            tags=self.tags,
            title=self.title,
            type=self.type,
            view_count=self.view_count)


def get_dashboards(id: Optional[_builtins.str] = None,
                   identifier: Optional[_builtins.str] = None,
                   name: Optional[_builtins.str] = None,
                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDashboardsResult:
    """
    Data source for retrieving a Harness Dashboard.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    dashboard = harness.platform.get_dashboards(id="id")
    ```


    :param _builtins.str id: Identifier of the dashboard.
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['identifier'] = identifier
    __args__['name'] = name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:platform/getDashboards:getDashboards', __args__, opts=opts, typ=GetDashboardsResult).value

    return AwaitableGetDashboardsResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        dashboard_id=pulumi.get(__ret__, 'dashboard_id'),
        data_sources=pulumi.get(__ret__, 'data_sources'),
        description=pulumi.get(__ret__, 'description'),
        folder_id=pulumi.get(__ret__, 'folder_id'),
        id=pulumi.get(__ret__, 'id'),
        identifier=pulumi.get(__ret__, 'identifier'),
        models=pulumi.get(__ret__, 'models'),
        name=pulumi.get(__ret__, 'name'),
        resource_identifier=pulumi.get(__ret__, 'resource_identifier'),
        tags=pulumi.get(__ret__, 'tags'),
        title=pulumi.get(__ret__, 'title'),
        type=pulumi.get(__ret__, 'type'),
        view_count=pulumi.get(__ret__, 'view_count'))
def get_dashboards_output(id: Optional[pulumi.Input[_builtins.str]] = None,
                          identifier: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          name: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDashboardsResult]:
    """
    Data source for retrieving a Harness Dashboard.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    dashboard = harness.platform.get_dashboards(id="id")
    ```


    :param _builtins.str id: Identifier of the dashboard.
    :param _builtins.str identifier: Unique identifier of the resource.
    :param _builtins.str name: Name of the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    __args__['identifier'] = identifier
    __args__['name'] = name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:platform/getDashboards:getDashboards', __args__, opts=opts, typ=GetDashboardsResult)
    return __ret__.apply(lambda __response__: GetDashboardsResult(
        created_at=pulumi.get(__response__, 'created_at'),
        dashboard_id=pulumi.get(__response__, 'dashboard_id'),
        data_sources=pulumi.get(__response__, 'data_sources'),
        description=pulumi.get(__response__, 'description'),
        folder_id=pulumi.get(__response__, 'folder_id'),
        id=pulumi.get(__response__, 'id'),
        identifier=pulumi.get(__response__, 'identifier'),
        models=pulumi.get(__response__, 'models'),
        name=pulumi.get(__response__, 'name'),
        resource_identifier=pulumi.get(__response__, 'resource_identifier'),
        tags=pulumi.get(__response__, 'tags'),
        title=pulumi.get(__response__, 'title'),
        type=pulumi.get(__response__, 'type'),
        view_count=pulumi.get(__response__, 'view_count')))
